import time

import requests
class getCountries:
    message = ""
    def getCountries(self):
        for x in range(19):
            offset=x*10
            url = "https://wft-geo-db.p.rapidapi.com/v1/geo/countries"

            querystring = {"offset": offset, "limit": "10"}

            headers = {
            'x-rapidapi-key': "32218ce6eemsh996ede13da25217p103011jsn32357c73ded7",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
            }

            response = requests.request("GET", url, headers=headers, params=querystring)
            countries = response.json()
            time.sleep(1.5)
            print([i['name'] for i in countries['data']])
            global message
            message = [i['name'] for i in countries['data']] + message
            i=0;
    def getMessage(self):
        global message
        return message


import requests

from myPackage.libPackage2.getCountriesByName import getCountriesByName


class getCities:
    message = ""
    def getCitiesPopOver(self):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/cities"
        querystring = {"minPopulation":"20000000"}
        headers = {
            'x-rapidapi-key': "32218ce6eemsh996ede13da25217p103011jsn32357c73ded7",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }
        response = requests.request("GET", url, headers=headers, params=querystring)
        city = response.json()
        print([i['city'] for i in city['data']])
        global message
        message = [i['city'] for i in city['data']]
    def getMessage(self):
        global message
        return message
def main():
    countries = getCountriesByName("r")
    countries.getCitiesByLetter()
    print(countries.getMessage())
if __name__ == '__main__':
    main();


import requests
class getAdministrativeDivisions:
    message = ""
    def getDivisionsForLetter(self):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/adminDivisions"

        querystring = {"minPopulation": "20000000"}

        headers = {
            'x-rapidapi-key': "32218ce6eemsh996ede13da25217p103011jsn32357c73ded7",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }

        response = requests.request("GET", url, headers=headers, params=querystring)
        city = response.json()
        print([i['name'] for i in city['data']])
        global message
        message = [i['name'] for i in city['data']]
    def getMessage(self):
        global message
        return message



import requests


class getCountriesByName:
    def __init__(self, litera):
        self.litera = litera
        message = "empty"
    def getCitiesByLetter(self):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/cities"
        querystring = {"namePrefix": self.litera}
        headers = {
            'x-rapidapi-key': "32218ce6eemsh996ede13da25217p103011jsn32357c73ded7",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }
        response = requests.request("GET", url, headers=headers, params=querystring)
        countries = response.json()
        print([i['name'] for i in countries['data']])
        global message
        message = [i['name'] for i in countries['data']]
    def getNumberOfCitiesbyLetter(self):
        url = "https://wft-geo-db.p.rapidapi.com/v1/geo/countries"

        querystring = {"namePrefix": self.litera}

        headers = {
            'x-rapidapi-key': "32218ce6eemsh996ede13da25217p103011jsn32357c73ded7",
            'x-rapidapi-host': "wft-geo-db.p.rapidapi.com"
        }

        response = requests.request("GET", url, headers=headers, params=querystring)
        countries = response.text
        print(countries[-5]+countries[-4]+countries[-3])
        global message
        message = (countries[-5]+countries[-4]+countries[-3])
    def getMessage(self):
        global message
        return message


from setuptools import setup

setup(
    name='PythonPip',
    version='1.1',
    packages=['myPackage', 'myPackage.libPackage', 'myPackage.libPackage2'],
    url='https://github.com/helmanso123/PythonLib/',
    license='MIT',
    author='Krzysztof Puciłowski',
    author_email='248405@student.pwr.edu.pl',
    description='first version'
)
